@@ -17,11 +17,11 @@ Catalyst::Plugin::Upload::Image::Magick::Thumbnail::Fixed - Making thumbnail ima
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -105,8 +105,6 @@ See also L<Image::Magick::Thumbnail>, L<Image::Magick::Thumbnail::Fixed>
 
     package Catalyst::Request::Upload;
 
-    __PACKAGE__->mk_accessors(qw/_thumbnail_fixed _thumbnail_temp/);
-
     sub thumbnail_fixed {
         my ( $self, $args ) = @_;
 
@@ -117,8 +115,8 @@ See also L<Image::Magick::Thumbnail>, L<Image::Magick::Thumbnail::Fixed>
             "This file is not image : " . $self->filename )
           unless ( $self->is_image );
 
-        unless ( $self->_thumbnail_fixed ) {
-            $self->_thumbnail_fixed( Image::Magick::Thumbnail::Fixed->new );
+        unless ( $self->{_thumbnail_fixed} ) {
+            $self->{_thumbnail_fixed} = Image::Magick::Thumbnail::Fixed->new;
         }
 
         if ( exists $args->{density} && $args->{density} =~ m|\d+x\d+| ) {
@@ -141,7 +139,7 @@ See also L<Image::Magick::Thumbnail>, L<Image::Magick::Thumbnail::Fixed>
             EXT      => $args->{format}
         );
 
-        eval { $self->_thumbnail_fixed->thumbnail(%$args); };
+        eval { $self->{_thumbnail_fixed}->thumbnail(%$args); };
         if ($@) {
             Catalyst::Exception->throw($@);
         }
@@ -154,8 +152,8 @@ See also L<Image::Magick::Thumbnail>, L<Image::Magick::Thumbnail::Fixed>
         $thumb->Read( $args->{output} );
 
 				### for File::Temp's cleanup
-				$self->_thumbnail_temp({}) unless ($self->_thumbnail_temp);
-				$self->_thumbnail_temp->{ $thumb->Get('filename') } = $args->{output};
+				$self->{_thumbnail_temp} = {} unless ($self->{_thumbnail_temp});
+				$self->{_thumbnail_temp}->{ $thumb->Get('filename') } = $args->{output};
 
 
         return $thumb;
@@ -207,6 +205,11 @@ L<http://search.cpan.org/dist/Catalyst-Plugin-Upload-Image-Magick>
 
 =head1 ACKNOWLEDGEMENTS
 
+=head1 Current Maintainer
+
+The current maintainer of this module is Adam Hopkins. Any questions or comments should be sent to him
+at srchulo@cpan.org
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2006 Toru Yamaguchi, all rights reserved.
